==> nted_0.24.1.orig.tar.gz: nted-0.24.1/commands/deletesystemcommand.h <==
/****************************************************************************************/
/*											*/
/* This program is free software; you can redistribute it and/or modify it under the	*/
/* terms of the GNU General Public License as published by the Free Software		*/
/* Foundation; either version 2 of the License, or (at your option) any later version.	*/
/*											*/
/* This program is distributed in the hope that it will be useful, but WITHOUT ANY	*/
/* WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A	*/
/* PARTICULAR PURPOSE. See the GNU General Public License for more details.		*/
/*											*/
/* You should have received a copy of the GNU General Public License along with this	*/
/* program; (See "COPYING"). If not, If not, see <http://www.gnu.org/licenses/>.        */
/*											*/
/*--------------------------------------------------------------------------------------*/
/*											*/
/*  Copyright   Joerg Anders, TU Chemnitz, Fakultaet fuer Informatik, GERMANY           */
/*		ja@informatik.tu-chemnitz.de						*/
/*											*/
/*											*/
/****************************************************************************************/

#ifndef DELETE_SYSTEM_COMMAND_H

#define DELETE_SYSTEM_COMMAND_H
#include "config.h"
#include "command.h"
#include <gtk/gtk.h>

class NedSystem;
class NedPage;

class NedDeleteSystemCommand : public NedCommand {
	public:	
		NedDeleteSystemCommand(NedPage *page, GList **systems_ptr, GList *system_ptr);
		virtual void execute(bool adjust = false);
		virtual void unexecute(bool adjust = false);
	private:
		GList **m_systems_ptr;
		GList *m_system_ptr;
		NedSystem *m_system;
		NedPage *m_page;
		int m_position;
};

#endif /* DELETE_SYSTEM_COMMAND_H */

==> nted_1.10.18.orig.tar.gz: nted-1.10.18/commands/deletesystemcommand.h <==
/****************************************************************************************/
/*											*/
/* This program is free software; you can redistribute it and/or modify it under the	*/
/* terms of the GNU General Public License as published by the Free Software		*/
/* Foundation; either version 2 of the License, or (at your option) any later version.	*/
/*											*/
/* This program is distributed in the hope that it will be useful, but WITHOUT ANY	*/
/* WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A	*/
/* PARTICULAR PURPOSE. See the GNU General Public License for more details.		*/
/*											*/
/* You should have received a copy of the GNU General Public License along with this	*/
/* program; (See "COPYING"). If not, If not, see <http://www.gnu.org/licenses/>.        */
/*											*/
/*--------------------------------------------------------------------------------------*/
/*											*/
/*  Copyright   Joerg Anders, TU Chemnitz, Fakultaet fuer Informatik, GERMANY           */
/*		ja@informatik.tu-chemnitz.de						*/
/*											*/
/*											*/
/****************************************************************************************/

#ifndef DELETE_SYSTEM_COMMAND_H

#define DELETE_SYSTEM_COMMAND_H
#include "config.h"
#include "command.h"
#include <gtk/gtk.h>

class NedSystem;
class NedPage;

class NedDeleteSystemCommand : public NedCommand {
	public:	
		NedDeleteSystemCommand(NedSystem *system);
		virtual void execute(bool adjust = false);
		virtual void unexecute(bool adjust = false);
	private:
		NedSystem *m_system;
		NedPage *m_page;
		GList *m_systems_pointer;
		int m_position;
};

#endif /* DELETE_SYSTEM_COMMAND_H */
